From: Stephen Frost <sfrost@snowman.net>
To: Andres Freund <andres@anarazel.de>
Cc: Tom Lane <tgl@sss.pgh.pa.us>
Cc: Amit Khandekar <amitdkhan.pg@gmail.com>
Cc: Andreas Joseph Krogh <andreas@visena.com>
Cc: Robert Haas <robertmhaas@gmail.com>
Cc: Alvaro Herrera <alvherre@2ndquadrant.com>
Cc: Jonathan S. Katz <jkatz@postgresql.org>
Cc: PostgreSQL Hackers <pgsql-hackers@lists.postgresql.org>
Subject: Re: Query is over 2x slower with jit=on
Date: Thu, 20 Sep 2018 09:07:21 -0400
Message-ID: <20180920130721.GM4184@tamriel.snowman.net> (raw)
In-Reply-To: <20180920033922.zi6n6vk7ilxaseu3@alap3.anarazel.de>
References: <VisenaEmail.27.cb06f4d2cef742ad.165627feef4@tc7-visena>
<20180822165155.tjbib4pewnbiyy4x@alap3.anarazel.de>
<CAJ3gD9cv2cbJ2t5zRZiWapNeRdgpM70++f80NbLwbEpM7uX2AQ@mail.gmail.com>
<20180910160909.qf3h3ttztvbyyuds@alap3.anarazel.de>
<CAJ3gD9fJcYofmWCe9hJ9Y6dUYU-qpkR=Bii+NhYufE7Mny9AHw@mail.gmail.com>
<CAJ3gD9cWBKnzXkhu30njaY1au3NO0XD=r4N3GcC_nwFbw5GYYw@mail.gmail.com>
<27812.1537221015@sss.pgh.pa.us>
<20180919224047.mcdjwis56ywqzhzs@alap3.anarazel.de>
<11291.1537414012@sss.pgh.pa.us>
<20180920033922.zi6n6vk7ilxaseu3@alap3.anarazel.de>
Greetings,
* Andres Freund (andres@anarazel.de) wrote:
> On 2018-09-19 23:26:52 -0400, Tom Lane wrote:
> > Andres Freund <andres@anarazel.de> writes:
> > > JIT:
> > > Functions: 2
> > > Generation Time: 0.680 ms
> > > Inlining: true
> > > Inlining Time: 7.591 ms
> > > Optimization: true
> > > Optimization Time: 20.522 ms
> > > Emission Time: 14.607 ms
[...]
> > > How about making that:
> > > JIT:
> > > Functions: 2
>
> FWIW, not that I want to do that now, but at some point it might make
> sense to sub-divide this into things like number of "expressions",
> "tuple deforming", "plans", ... Just mentioning that if somebody wants
> to comment on reformatting this as well, if we're tinkering anyway.
I'd actually think we'd maybe want some kind of 'verbose' mode which
shows exactly what got JIT'd and what didn't- one of the questions that
I think people will be asking is "why didn't X get JIT'd?" and I don't
think that's very easy to figure out currently.
> > > Options: Inlining, Optimization
> > > Times (Total, Generation, Inlining, Optimization, Emission): 43.4 ms, 0.680 ms, 7.591 ms, 20.522 ms, 14.607 ms
> >
> > > or something similar?
> >
> > That's going in the right direction. Personally I'd make the last line
> > more like
> >
> > Times: generation 0.680 ms, inlining 7.591 ms, optimization 20.522 ms, emission 14.607 ms, total 43.4 ms
>
> Yea, that's probably easier to read.
I tend to agree that it's easier to read but I'm not sure we need to
quite go that far in reducing the number of rows.
> > (total at the end seems more natural to me, YMMV).
I agree with this..
> I kind of think doing it first is best, because that's usually the first
> thing one wants to know.
and this, so what about:
Times:
generation 0.680 ms, inlining 7.591 ms, optimization 20.522 ms, emission 14.607 ms
Total: 43.4 ms
Gets the total out there quick on the left where you're scanning down
while keeping the detailed info above for reviewing after.
> > Also, the "options" format you suggest here seems a bit too biased
> > towards binary on/off options --- what happens when there's a
> > three-way option? So maybe that line should be like
> >
> > Options: inlining on, optimization on
> >
> > though I'm less sure about that part.
>
> I'm pretty certain you're right :). There's already arguments around
> making optimization more gradual (akin to O1,2,3).
That certainly sounds like it'd be very neat to have though I wonder how
well we'll be able to automatically plan out which optimization level to
use when..
Thanks!
Stephen
Attachments:
signature.asc (application/pgp-signature, 818B) download
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-hackers@postgresql.org
Cc: sfrost@snowman.net, andres@anarazel.de, tgl@sss.pgh.pa.us, amitdkhan.pg@gmail.com, andreas@visena.com, robertmhaas@gmail.com, alvherre@2ndquadrant.com, jkatz@postgresql.org, pgsql-hackers@lists.postgresql.org
Subject: Re: Query is over 2x slower with jit=on
In-Reply-To: <20180920130721.GM4184@tamriel.snowman.net>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox